==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TimeChaosSpecFluent<A extends TimeChaosSpecFluent<A>> extends Fluent<A>{
  public A addToClockIds(Integer index,String item);
  public A setToClockIds(Integer index,String item);
  public A addToClockIds(java.lang.String... items);
  public A addAllToClockIds(Collection<String> items);
  public A removeFromClockIds(java.lang.String... items);
  public A removeAllFromClockIds(Collection<String> items);
  public List<String> getClockIds();
  public String getClockId(Integer index);
  public String getFirstClockId();
  public String getLastClockId();
  public String getMatchingClockId(Predicate<String> predicate);
  public Boolean hasMatchingClockId(Predicate<String> predicate);
  public A withClockIds(List<String> clockIds);
  public A withClockIds(java.lang.String... clockIds);
  public Boolean hasClockIds();
  public A addToContainerNames(Integer index,String item);
  public A setToContainerNames(Integer index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(Integer index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public TimeChaosSpecFluent.SelectorNested<A> withNewSelector();
  public TimeChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public TimeChaosSpecFluent.SelectorNested<A> editSelector();
  public TimeChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public TimeChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getTimeOffset();
  public A withTimeOffset(String timeOffset);
  public Boolean hasTimeOffset();
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<TimeChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/TimeChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TimeChaosSpecFluent<A extends TimeChaosSpecFluent<A>> extends Fluent<A>{
  public A addToClockIds(int index,String item);
  public A setToClockIds(int index,String item);
  public A addToClockIds(java.lang.String... items);
  public A addAllToClockIds(Collection<String> items);
  public A removeFromClockIds(java.lang.String... items);
  public A removeAllFromClockIds(Collection<String> items);
  public List<String> getClockIds();
  public String getClockId(int index);
  public String getFirstClockId();
  public String getLastClockId();
  public String getMatchingClockId(Predicate<String> predicate);
  public Boolean hasMatchingClockId(Predicate<String> predicate);
  public A withClockIds(List<String> clockIds);
  public A withClockIds(java.lang.String... clockIds);
  public Boolean hasClockIds();
  public A addToContainerNames(int index,String item);
  public A setToContainerNames(int index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(int index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public TimeChaosSpecFluent.SelectorNested<A> withNewSelector();
  public TimeChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public TimeChaosSpecFluent.SelectorNested<A> editSelector();
  public TimeChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public TimeChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getTimeOffset();
  public A withTimeOffset(String timeOffset);
  public Boolean hasTimeOffset();
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<TimeChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
